=== modified file '.bzrignore'
--- .bzrignore	2010-10-08 08:15:14 +0000
+++ .bzrignore	2010-10-13 00:26:41 +0000
@@ -20,6 +20,7 @@
 ./doc/developers/performance.png
 ./doc/en/user-reference/*.txt
 ./doc/en/release-notes/index.txt
+./doc/en/release-notes/NEWS.txt
 BRANCH-INFO
 # setup.py working directory
 ./build

=== modified file 'Makefile'
--- Makefile	2010-10-08 08:15:14 +0000
+++ Makefile	2010-10-13 00:26:41 +0000
@@ -306,8 +306,8 @@
 %.html: %.txt
 	$(rst2html) --stylesheet=../../default.css $< $@
 
-doc/en/release-notes/NEWS.txt: NEWS
-	$(PYTHON) -c "import shutil; shutil.copyfile('$<', '$@')"
+doc/en/release-notes/NEWS.txt: $(NEWS_FILES) tools/generate_release_notes.py
+	$(PYTHON) tools/generate_release_notes.py $@ $(NEWS_FILES)
 
 upgrade_guide_dependencies =  $(wildcard $(addsuffix /*.txt, doc/en/upgrade-guide)) 
 

=== modified file 'tools/generate_release_notes.py'
--- tools/generate_release_notes.py	2010-10-08 08:42:43 +0000
+++ tools/generate_release_notes.py	2010-10-13 00:26:41 +0000
@@ -33,7 +33,18 @@
 from optparse import OptionParser
 
 
-preamble = """\
+preamble_plain = """\
+####################
+Bazaar Release Notes
+####################
+
+
+.. contents:: List of Releases
+   :depth: 2
+
+"""
+
+preamble_sphinx = """\
 ####################
 Bazaar Release Notes
 ####################
@@ -53,6 +64,7 @@
         >>> natural_sort_key('bzr-1.10b1.txt') > natural_sort_key('bzr-1.2.txt')
         True
     """
+    file_name = os.path.basename(file_name)
     parts = re.findall(r'(?:[0-9]+|[^0-9]+)', file_name)
     result = []
     for part in parts:
@@ -62,6 +74,37 @@
     return tuple(result)
 
 
+def output_news_file_sphinx(out_file, news_file_name):
+    news_file_name = os.path.basename(news_file_name)
+    if not news_file_name.endswith('.txt'):
+        raise AssertionError(
+            'NEWS file %s does not have .txt extension.'
+            % (news_file_name,))
+    doc_name = news_file_name[:-4]
+    link_text = doc_name.replace('-', ' ')
+    out_file.write('   %s <%s>\n' % (link_text, doc_name))
+
+
+def output_news_file_plain(out_file, news_file_name):
+    f = open(news_file_name, 'rb')
+    try:
+        lines = f.readlines()
+    finally:
+        f.close()
+    title = os.path.basename(news_file_name)[len('bzr-'):-len('.txt')]
+    for line in lines:
+        if line == '####################\n':
+            line = '#' * len(title) + '\n'
+        elif line == 'Bazaar Release Notes\n':
+            line = title + '\n'
+        elif line == '.. toctree::\n':
+            continue
+        elif line == '   :maxdepth: 1\n':
+            continue
+        out_file.write(line)
+    out_file.write('\n\n')
+
+
 def main(argv):
     # Check usage
     parser = OptionParser(usage="%prog OUTPUT_FILE NEWS_FILE [NEWS_FILE ...]")
@@ -72,21 +115,20 @@
 
     # Open the files and do the work
     out_file_name = args[0]
-    news_file_names = map(os.path.basename, args[1:])
-    news_file_names = sorted(news_file_names, key=natural_sort_key,
-        reverse=True)
+    news_file_names = sorted(args[1:], key=natural_sort_key, reverse=True)
+
+    if out_file_name == 'index.txt':
+        preamble = preamble_sphinx
+        output_news_file = output_news_file_sphinx
+    else:
+        preamble = preamble_plain
+        output_news_file = output_news_file_plain
 
     out_file = open(out_file_name, 'w')
     try:
         out_file.write(preamble)
         for news_file_name in news_file_names:
-            if not news_file_name.endswith('.txt'):
-                raise AssertionError(
-                    'NEWS file %s does not have .txt extension.'
-                    % (news_file_name,))
-            doc_name = news_file_name[:-4]
-            link_text = doc_name.replace('-', ' ')
-            out_file.write('   %s <%s>\n' % (link_text, doc_name))
+            output_news_file(out_file, news_file_name)
     finally:
         out_file.close()
 

